// AUTOGENERATED FILE - DO NOT EDIT

var pt = window.PropTypes;
var pk = window['dash_extensions'];

pk.BeforeAfter.propTypes = {id:pt.string,
 setProps:pt.any,
 height:pt.string,
 width:pt.string,
 hover:pt.bool,
 value:pt.number,
 direction:pt.oneOf(["'horizontal'", "'vertical'"]),
 keyboard:pt.oneOf(["'enabled'", "'disabled'"]),
 before:pt.object,
 after:pt.object};
pk.CycleBreaker.propTypes = {id:pt.string,
 setProps:pt.any,
 src:pt.any,
 dst:pt.any};
pk.DeferScript.propTypes = {id:pt.string,
 setProps:pt.any,
 src:pt.string};
pk.EventListener.propTypes = {id:pt.string,
 setProps:pt.any,
 events:pt.arrayOf(pt.shape({event:pt.string,props:pt.arrayOf(pt.string)})),
 logging:pt.bool,
 children:pt.node,
 style:pt.any,
 className:pt.string,
 event:pt.object,
 n_events:pt.number,
 useCapture:pt.bool};
pk.EventSource.propTypes = {id:pt.string,
 setProps:pt.any,
 close:pt.bool,
 error:pt.string,
 message:pt.string,
 readyState:pt.oneOf([0, 1, 2]),
 withCredentials:pt.bool,
 url:pt.string};
pk.Keyboard.propTypes = {id:pt.string,
 setProps:pt.any,
 children:pt.node,
 style:pt.any,
 className:pt.string,
 eventProps:pt.arrayOf(pt.string),
 captureKeys:pt.arrayOf(pt.oneOfType([pt.string,pt.objectOf(pt.any)])),
 keydown:pt.objectOf(pt.any),
 keyup:pt.objectOf(pt.any),
 keys_pressed:pt.objectOf(pt.any),
 n_keydowns:pt.number,
 n_keyups:pt.number,
 useCapture:pt.bool};
pk.Loading.propTypes = {id:pt.string,
 setProps:pt.any,
 preventDefault:pt.arrayOf(pt.string),
 children:pt.node,
 loading_state:pt.shape({is_loading:pt.bool,prop_name:pt.string,component_name:pt.string})};
pk.Lottie.propTypes = {id:pt.string,
 setProps:pt.any,
 url:pt.string,
 speed:pt.number,
 action:pt.oneOf(["'play'", "'pause'", "'stop'"]),
 options:pt.object};
pk.Mermaid.propTypes = {id:pt.string,
 setProps:pt.any,
 chart:pt.string,
 name:pt.string,
 config:pt.objectOf(pt.any),
 className:pt.string};
pk.Purify.propTypes = {id:pt.string,
 setProps:pt.any,
 html:pt.string,
 config:pt.objectOf(pt.any),
 className:pt.string};
pk.SSE.propTypes = {id:pt.string,
 setProps:pt.any,
 options:pt.shape({headers:pt.objectOf(pt.string),payload:pt.oneOfType([pt.string]),method:pt.string,withCredentials:pt.bool,start:pt.bool,debug:pt.bool}),
 url:pt.string,
 concat:pt.bool,
 animate_delay:pt.number,
 animate_chunk:pt.number,
 animate_prefix:pt.string,
 animate_suffix:pt.string,
 value:pt.string,
 animation:pt.string,
 done:pt.bool};
pk.WebSocket.propTypes = {id:pt.string,
 setProps:pt.any,
 state:pt.any,
 message:pt.any,
 error:pt.any,
 send:pt.any,
 url:pt.string,
 protocols:pt.arrayOf(pt.string),
 timeout:pt.number};
